@@ -9,14 +9,14 @@ from metaphor.common.metadata_change_event import (
     DatasetLogicalID,
     EntityType,
     GroupID,
-    PersonID,
+    PersonLogicalID,
 )
 
 
 @dataclass
 class EntityId:
     type: EntityType
-    logicalId: Union[DatasetLogicalID, DashboardLogicalID, PersonID, GroupID]
+    logicalId: Union[DatasetLogicalID, DashboardLogicalID, PersonLogicalID, GroupID]
 
     def __str__(self) -> str:
         json = encode_canonical_json(self.logicalId.to_dict())
