@@ -21,8 +21,7 @@ def handle_api(
 def _handle_api(
     event, context, config_cls: Type[RunConfig], extractor_cls: Type[BaseExtractor]
 ):
-    params = json.loads(event["body"]) if "body" in event else event["params"]
-    config_file = params.get("config_file", None)
+    config_file = event.get("config_file", None)
     if config_file is None:
         return {"statusCode": 422, "body": "Missing 'config_file' parameter"}
 
@@ -33,4 +32,4 @@ def _handle_api(
 
     actor = extractor_cls()
     actor.run(config=run_config)
-    return {"statusCode": 200, "body": json.dumps(params)}
+    return {"statusCode": 200, "body": json.dumps(event)}
