@@ -577,7 +577,7 @@ class GroupOwner:
 
 
 @dataclass
-class PersonID:
+class PersonLogicalID:
     """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
@@ -587,10 +587,10 @@ class PersonID:
     email: Optional[str] = None
 
     @staticmethod
-    def from_dict(obj: Any) -> 'PersonID':
+    def from_dict(obj: Any) -> 'PersonLogicalID':
         assert isinstance(obj, dict)
         email = from_union([from_str, from_none], obj.get("email"))
-        return PersonID(email)
+        return PersonLogicalID(email)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -600,19 +600,19 @@ class PersonID:
 
 @dataclass
 class PersonOwner:
-    person: Optional[PersonID] = None
+    person: Optional[PersonLogicalID] = None
     role: Optional[str] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'PersonOwner':
         assert isinstance(obj, dict)
-        person = from_union([PersonID.from_dict, from_none], obj.get("person"))
+        person = from_union([PersonLogicalID.from_dict, from_none], obj.get("person"))
         role = from_union([from_str, from_none], obj.get("role"))
         return PersonOwner(person, role)
 
     def to_dict(self) -> dict:
         result: dict = {}
-        result["person"] = from_union([lambda x: to_class(PersonID, x), from_none], self.person)
+        result["person"] = from_union([lambda x: to_class(PersonLogicalID, x), from_none], self.person)
         result["role"] = from_union([from_str, from_none], self.role)
         return result
 
@@ -1154,42 +1154,42 @@ class EventHeader:
 @dataclass
 class GroupInfo:
     id: Optional[ObjectID] = None
-    admins: Optional[List[PersonID]] = None
+    admins: Optional[List[PersonLogicalID]] = None
     aspect_type: Optional[AspectType] = None
     created_at: Optional[datetime] = None
     email: Optional[str] = None
     entity_id: Optional[str] = None
     group_info_id: Optional[str] = None
     latest: Optional[bool] = None
-    members: Optional[List[PersonID]] = None
+    members: Optional[List[PersonLogicalID]] = None
     subgroups: Optional[List[GroupID]] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'GroupInfo':
         assert isinstance(obj, dict)
         id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
-        admins = from_union([lambda x: from_list(PersonID.from_dict, x), from_none], obj.get("admins"))
+        admins = from_union([lambda x: from_list(PersonLogicalID.from_dict, x), from_none], obj.get("admins"))
         aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
         email = from_union([from_str, from_none], obj.get("email"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         group_info_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
-        members = from_union([lambda x: from_list(PersonID.from_dict, x), from_none], obj.get("members"))
+        members = from_union([lambda x: from_list(PersonLogicalID.from_dict, x), from_none], obj.get("members"))
         subgroups = from_union([lambda x: from_list(GroupID.from_dict, x), from_none], obj.get("subgroups"))
         return GroupInfo(id, admins, aspect_type, created_at, email, entity_id, group_info_id, latest, members, subgroups)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
-        result["admins"] = from_union([lambda x: from_list(lambda x: to_class(PersonID, x), x), from_none], self.admins)
+        result["admins"] = from_union([lambda x: from_list(lambda x: to_class(PersonLogicalID, x), x), from_none], self.admins)
         result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
         result["email"] = from_union([from_str, from_none], self.email)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.group_info_id)
         result["latest"] = from_union([from_bool, from_none], self.latest)
-        result["members"] = from_union([lambda x: from_list(lambda x: to_class(PersonID, x), x), from_none], self.members)
+        result["members"] = from_union([lambda x: from_list(lambda x: to_class(PersonLogicalID, x), x), from_none], self.members)
         result["subgroups"] = from_union([lambda x: from_list(lambda x: to_class(GroupID, x), x), from_none], self.subgroups)
         return result
 
@@ -1310,7 +1310,7 @@ class PersonOrganization:
     groups: Optional[List[GroupID]] = None
     person_organization_id: Optional[str] = None
     latest: Optional[bool] = None
-    manager: Optional[PersonID] = None
+    manager: Optional[PersonLogicalID] = None
     manager_id: Optional[str] = None
     manager_name: Optional[str] = None
     name: Optional[str] = None
@@ -1329,7 +1329,7 @@ class PersonOrganization:
         groups = from_union([lambda x: from_list(GroupID.from_dict, x), from_none], obj.get("groups"))
         person_organization_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
-        manager = from_union([PersonID.from_dict, from_none], obj.get("manager"))
+        manager = from_union([PersonLogicalID.from_dict, from_none], obj.get("manager"))
         manager_id = from_union([from_str, from_none], obj.get("managerId"))
         manager_name = from_union([from_str, from_none], obj.get("managerName"))
         name = from_union([from_str, from_none], obj.get("name"))
@@ -1348,7 +1348,7 @@ class PersonOrganization:
         result["groups"] = from_union([lambda x: from_list(lambda x: to_class(GroupID, x), x), from_none], self.groups)
         result["id"] = from_union([from_str, from_none], self.person_organization_id)
         result["latest"] = from_union([from_bool, from_none], self.latest)
-        result["manager"] = from_union([lambda x: to_class(PersonID, x), from_none], self.manager)
+        result["manager"] = from_union([lambda x: to_class(PersonLogicalID, x), from_none], self.manager)
         result["managerId"] = from_union([from_str, from_none], self.manager_id)
         result["managerName"] = from_union([from_str, from_none], self.manager_name)
         result["name"] = from_union([from_str, from_none], self.name)
@@ -1499,7 +1499,7 @@ class Person:
     instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
-    logical_id: Optional[PersonID] = None
+    logical_id: Optional[PersonLogicalID] = None
     organization: Optional[PersonOrganization] = None
     password: Optional[str] = None
     properties: Optional[PersonProperties] = None
@@ -1519,7 +1519,7 @@ class Person:
         person_id = from_union([from_str, from_none], obj.get("id"))
         last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
         last_name = from_union([from_str, from_none], obj.get("lastName"))
-        logical_id = from_union([PersonID.from_dict, from_none], obj.get("logicalId"))
+        logical_id = from_union([PersonLogicalID.from_dict, from_none], obj.get("logicalId"))
         organization = from_union([PersonOrganization.from_dict, from_none], obj.get("organization"))
         password = from_union([from_str, from_none], obj.get("password"))
         properties = from_union([PersonProperties.from_dict, from_none], obj.get("properties"))
@@ -1539,7 +1539,7 @@ class Person:
         result["id"] = from_union([from_str, from_none], self.person_id)
         result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
         result["lastName"] = from_union([from_str, from_none], self.last_name)
-        result["logicalId"] = from_union([lambda x: to_class(PersonID, x), from_none], self.logical_id)
+        result["logicalId"] = from_union([lambda x: to_class(PersonLogicalID, x), from_none], self.logical_id)
         result["organization"] = from_union([lambda x: to_class(PersonOrganization, x), from_none], self.organization)
         result["password"] = from_union([from_str, from_none], self.password)
         result["properties"] = from_union([lambda x: to_class(PersonProperties, x), from_none], self.properties)
