@@ -13,13 +13,15 @@ logger.setLevel(logging.INFO)
 class Sink(ABC):
     """Base class for metadata sinks"""
 
-    def send_messages(self, events: List[MetadataChangeEvent]) -> None:
+    def send_messages(self, events: List[MetadataChangeEvent]) -> bool:
         """Send MCE messages to ingestion pipeline"""
         records = [EventUtil.trim_event(e) for e in events]
         valid_records = [r for r in records if EventUtil.validate_message(r)]
         logger.debug(f"Records: {json.dumps(valid_records)}")
-        if valid_records:
-            self._sink(valid_records)
+        if len(valid_records) == 0:
+            return False
+
+        return self._sink(valid_records)
 
     @staticmethod
     def _chunks(records: List, n: int) -> Generator[List, None, None]:
@@ -28,5 +30,5 @@ class Sink(ABC):
             yield records[i : i + n]
 
     @abstractmethod
-    def _sink(self, messages: List[dict]) -> None:
+    def _sink(self, messages: List[dict]) -> bool:
         """Sink metadata records to ingestion pipeline, should be overridden"""
