@@ -23,7 +23,7 @@ from metaphor.common.metadata_change_event import (
     FieldDocumentation,
     MetadataChangeEvent,
     Ownership,
-    PersonID,
+    PersonLogicalID,
     PersonOwner,
     SchemaField,
     SchemaType,
@@ -262,7 +262,7 @@ class DbtExtractor(BaseExtractor):
     @staticmethod
     def _build_owner(db_owner: str) -> PersonOwner:
         owner = PersonOwner()
-        owner.person = PersonID(db_owner)
+        owner.person = PersonLogicalID(db_owner)
         owner.role = "DB_TABLE_OWNER"
         return owner
 
