@@ -17,7 +17,7 @@ from metaphor.common.metadata_change_event import (
     GroupInfo,
     MetadataChangeEvent,
     Person,
-    PersonID,
+    PersonLogicalID,
     PersonProperties,
 )
 
@@ -108,7 +108,7 @@ class GoogleDirectoryExtractor(BaseExtractor):
     def _parse_user(self, user: Dict) -> None:
         person = Person()
         person.entity_type = EntityType.PERSON
-        person.logical_id = PersonID()
+        person.logical_id = PersonLogicalID()
         person.logical_id.email = user["primaryEmail"]
 
         person.properties = PersonProperties()
@@ -134,7 +134,7 @@ class GoogleDirectoryExtractor(BaseExtractor):
         for member in members:
             # TODO: get subgroups instead of derived members
             if member["type"] == "USER":
-                user = PersonID()
+                user = PersonLogicalID()
                 user.email = member["email"]
 
                 if member["role"] in ["OWNER", "MANAGER"]:
