@@ -1,5 +1,5 @@
 try:
-    import unzip_requirements
+    import unzip_requirements  # noqa: F401
 except ImportError:
     pass
 
