@@ -23,7 +23,6 @@ from metaphor.common.metadata_change_event import (
     DashboardPlatform,
     DashboardUpstream,
     DataPlatform,
-    DatasetLogicalID,
     EntityType,
     MetadataChangeEvent,
 )
@@ -170,7 +169,7 @@ class LookerExtractor(BaseExtractor):
         model_map: Dict[str, Model],
     ) -> Tuple[List[Chart], DashboardUpstream]:
 
-        dataset_ids: Set[DatasetLogicalID] = set()
+        dataset_ids: Set[str] = set()
         charts = []
         for e in filter(lambda e: e.type == "vis", dashboard_elements):
 
@@ -207,11 +206,14 @@ class LookerExtractor(BaseExtractor):
                         f"Chart {e.title} references invalid explore {f.view}"
                     )
 
-                dataset_ids.update(explore.upstream_datasets)
+                for id in explore.upstream_datasets:
+                    dataset_ids.add(str(id))
 
         return (
             charts,
             DashboardUpstream(
-                aspect_type=AspectType.DASHBOARD_UPSTREAM, sources=list(dataset_ids)
+                aspect_type=AspectType.DASHBOARD_UPSTREAM,
+                source_datasets=list(dataset_ids),
+                sources=[],  # TODO: Remove after the deprecated field is dropped
             ),
         )
