@@ -1,10 +1,10 @@
 try:
-    import unzip_requirements
+    import unzip_requirements  # noqa: F401
 except ImportError:
     pass
 
 from metaphor.common.handler import handle_api
-from metaphor.postgresql import PostgresqlExtractor, PostgresqlRunConfig
+from metaphor.postgresql.extractor import PostgresqlExtractor, PostgresqlRunConfig
 
 
 def handle(event, context):
